package be.iminds.ilabt.jfed.highlevel.util;

import be.iminds.ilabt.jfed.espec.util.ChModPermissionsUtil;
import net.schmizz.sshj.xfer.InMemorySourceFile;
import net.schmizz.sshj.xfer.LocalFileFilter;
import net.schmizz.sshj.xfer.LocalSourceFile;

import javax.annotation.Nonnull;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * ByteArraySshjFile: Implements a Sshj InMemorySourceFile backed by a byte array
 */
public class ByteArraySshjFile extends InMemorySourceFile {
    @Nonnull private final byte[] bytes;
    private final String name;
    private final int permissions;

    public ByteArraySshjFile(String name, @Nonnull byte[] bytes, String chmodStylePermissions) {
        this.bytes = bytes;
        this.name = name;
        this.permissions = ChModPermissionsUtil.toMask(chmodStylePermissions);
    }

    @Override
    public boolean isFile() {
        return true;
    }

    @Override
    public boolean isDirectory() {
        return false;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public long getLength() {
        return bytes.length;
    }

    @Override
    public InputStream getInputStream() throws IOException {
        return new ByteArrayInputStream(bytes);
    }

    @Override
    public int getPermissions() throws IOException {
        return permissions;
    }

    @Override
    public boolean providesAtimeMtime() {
        return false;
    }

    @Override
    public long getLastAccessTime() throws IOException {
        return super.getLastAccessTime();
    }

    @Override
    public long getLastModifiedTime() throws IOException {
        return super.getLastModifiedTime();
    }

    @Override
    public Iterable<? extends LocalSourceFile> getChildren(LocalFileFilter filter) throws IOException {
        return super.getChildren(filter);
    }
}
